<?php
/*
** Zabbix
** Copyright (C) 2001-2018 NeoKylin Project
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
**/


require_once dirname(__FILE__).'/config.inc.php';

// if we include footer in some function
if (!isset($page)) {
	global $page;
}

if (!defined('PAGE_HEADER_LOADED')) {
	define('PAGE_HEADER_LOADED', 1);
}

// last page
if (!defined('ZBX_PAGE_NO_MENU') && $page['file'] != 'profile.php') {
	CProfile::update('web.paging.lastpage', $page['file'], PROFILE_TYPE_STR);
}

if (CProfile::isModified()) {
	DBstart();
	$result = CProfile::flush();
	DBend($result);
}

// end transactions if they have not been closed already
if (isset($DB) && isset($DB['TRANSACTIONS']) && $DB['TRANSACTIONS'] != 0) {
	error(_('Transaction has not been closed. Aborting...'));
	DBend(false);
}

show_messages();

if ($page['type'] == PAGE_TYPE_HTML) {
	// end of article div
	echo '</main>'."\n";
	if (!defined('ZBX_PAGE_NO_MENU')) {
		makePageFooter()->show();
	}
	insertPagePostJs();
	require_once 'include/views/js/common.init.js.php';

	if (in_array($page['type'], [PAGE_TYPE_HTML_BLOCK, PAGE_TYPE_HTML])) {
		if (!is_null(CWebUser::$data) && isset(CWebUser::$data['debug_mode'])
				&& CWebUser::$data['debug_mode'] == GROUP_DEBUG_MODE_ENABLED) {
			CProfiler::getInstance()->stop();
			CProfiler::getInstance()->show();
			makeDebugButton()->show();
		}
	}
	echo '
<style type="text/css">
    #body {
        text-align: center;
        color: #768d99;
        background: #ebeef0;
        width: 100%;
        height: 100%;
    }

@-webkit-keyframes animate-width {
  0% {
    width: 0;
  }
  100% {
    visibility: visible;
  }
}
@keyframes animate-width {
  0% {
    width: 0;
  }
  100% {
    visibility: visible;
  }
}
@-webkit-keyframes animate-height {
  0% {
    height: 0;
  }
  100% {
    visibility: visible;
  }
}
@-moz-keyframes animate-height {
  0% {
    height: 0;
  }
  100% {
    visibility: visible;
  }
}

#bar-chart {
  height: 380px;
  width: 25%;
  position: relative;
  margin: 50px auto 0;
}
#bar-chart * {
  box-sizing: border-box;
}
#bar-chart .graph {
  height: 283px;
  position: relative;
}
#bar-chart .bars {
  height: 253px;
  padding: 0 5%;
  position: absolute;
  width: 105%;
  z-index: 10;
}
#bar-chart .bar-group {
  display: block;
  float: left;
  height: 100%;
  position: relative;
  width: 100%;
  margin-right: 20%;
}
#bar-chart .bar-group:last-child {
  margin-right: 0;
}
#bar-chart .bar-group .bar {
  visibility: hidden;
  height: 0;
  -webkit-animation: animate-height;
  -moz-animation: animate-height;
  animation: animate-height;
  animation-timing-function: cubic-bezier(0.35, 0.95, 0.67, 0.99);
  -webkit-animation-timing-function: cubic-bezier(0.35, 0.95, 0.67, 0.99);
  -moz-animation-timing-function: cubic-bezier(0.35, 0.95, 0.67, 0.99);
  animation-duration: 0.4s;
  -webkit-animation-duration: 0.4s;
  -moz-animation-duration: 0.4s;
  animation-fill-mode: forwards;
  -webkit-animation-fill-mode: forwards;
  box-shadow: 1px 0 2px rgba(0, 0, 0, 0.15);
  border: 1px solid #2d2d2d;
  border-radius: 3px 3px 0 0;
  bottom: 0;
  cursor: pointer;
  height: 0;
  position: absolute;
  text-align: center;
  width: 40%;
}
#bar-chart .bar-group .bar:nth-child(2) {
  left: 50%;
}
#bar-chart .bar-group .bar span {
  display: none;
}
#bar-chart .bar-group .bar-1 {
  animation-delay: 0.3s;
  -webkit-animation-delay: 0.3s;
}
#bar-chart .bar-group .bar-2 {
  animation-delay: 0.6s;
  -webkit-animation-delay: 0.6s;
}
#bar-chart ul {
  list-style: none;
  margin: 0;
  padding: 0;
}
#bar-chart .x-axis {
  bottom: 0;
  position: absolute;
  text-align: left;
  width: 105%;
}
#bar-chart .x-axis li {
  float: left;
  margin-right: 10%;
  font-size: 11px;
  width: 40%;
}
#bar-chart .y-axis {
  position: absolute;
  text-align: right;
  width: 95%;
}
#bar-chart .y-axis li {
  border-top: 1px solid #4e5464;
  display: block;
  height: 63.25px;
  width: 100%;
}
#bar-chart .y-axis li span {
  display: block;
  font-size: 11px;
  margin: -10px 0 0 -60px;
  padding: 0 10px;
  width: 40px;
}
#bar-chart .stat-1 {
  background-image: -webkit-linear-gradient(left, #0275b8 0%, #0275b8 47%, #0275b8 50%, #0275b8 100%);
  background-image: linear-gradient(to right, #0275b8 0%, #0275b8 47%, #0275b8 50%, #0275b8 100%);
}
#bar-chart .stat-2 {
  background-image: -webkit-linear-gradient(left, #FFA059 0%, #FFA059 47%, #FFA059 50%, #FFA059 100%);
  background-image: linear-gradient(to right, #FFA059 0%, #FFA059 47%, #FFA059 50%, #FFA059 100%);
}

.left {
    width: 0%;    /*这里是百分比或者像素值，对应下面的center就是百分比或者像素值*/
	height: 400px;
	background: white;
	float: left;
}
.topleft {
	width: 0%;    /*这里是百分比或者像素值，对应下面的center就是百分比或者像素值*/
	height: 400px;
	background: white;
	float: left;
}    
.topright {
    width: 50%;  /*这里是百分比或者像素值，对应下面的center就是百分比或者像素值*/
	height: 400px;
	background: white;
	float: right;
	margin: auto;
}  
.right {
    width: 50%;  /*这里是百分比或者像素值，对应下面的center就是百分比或者像素值*/
	height: 400px;
	background: white;
	float: right;
	margin: auto;
}
.center {
	height: 400px;
	background: white;
	margin: auto;
	margin-left:0%;
	margin-right:50%;
}
.selector_container {
        margin:2px 0 0 0;
        position: absolute;
        z-index:9999;
        right:0;
}
.selector {
        margin: 0 5px 0 0;
        float:right;
}
.register_info {
    margin:20px 0 0 0;
    position: absolute;
    z-index:9999;
    //float: right;
    right: 0;
    bottom: 0px;
}
.top_center {
	/*position: absolute;
	height: 200px;
	background: white;
	//margin: auto;
	left: 0;
	//margin-left:0%;
	//margin-right:40%;
	width:40%;*/
	

	float:left;
	height: 200px;
	background: white;
	width:40%;
}
.top_label {
	/*
	position: absolute;
	height: 200px;
	background: white;
	//margin: auto;
	//margin-left:80%;
	//margin-right:100%;
	width: 20%;
	right:0;
	bottom:1px;*/
	
	float:right;
	height: 200px;
	background: white;
	width: 15%;

}
.top_right {
	/*left:40%;
	//position: absolute;
    width: 40%;  /*这里是百分比或者像素值，对应下面的center就是百分比或者像素值*/
	height: 200px;
	background: white;
	//float: right;
	margin: left;*/
	
	float:left;
	margin-left:40%;
	//width: 42%;  /*这里是百分比或者像素值，对应下面的center就是百分比或者像素值*/
	
	margin-right:15.1%;
	height: 200px;
	background: white;
}

</style>
<meta charset="UTF-8">
<body>
//<script>

//var neoa=neoy+neon;
//var persy=100*neoy/neoa;
//var persn=100*neon/neoa;
//persy=persy.toFixed(2);
//persn=persn.toFixed(2);
//var line1=neoa/4;
//var line2=2*neoa/4;
//var line3=3*neoa/4;
//var line4=neoa;
//line1=line1.toFixed(0);
//line2=line2.toFixed(0);
//line3=line3.toFixed(0);
</script>
';


/**将查询到的datenote分割成年份和对应的月份 */
function dates_for_display($arr_all_date){
        $show_date=[];
        foreach($arr_all_date as $temp_all_date){
            $year_of_date=(int)floor($temp_all_date/10000);
            if(!array_key_exists($year_of_date,$show_date)){
                
                $month_of_year=[];//未定义则置空
                
                $show_date[$year_of_date]=[];  //未定义则定义                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   
            }
            //push month into belonging year
            array_push($month_of_year,(int)floor(($temp_all_date%10000)/100));
            $month_of_year=array_unique($month_of_year);
            $show_date[$year_of_date]=$month_of_year;
        }
        return $show_date;
    //}
}
/**分割日期后的索引数组 */
$show_date = dates_for_display($arr_all_date);

echo '<script>var onlineamount=';
echo (int)$onlineamount;
echo ';
     var registeramount=';
echo (int)$registeramount;
echo ';</script>';

//include Echarts js file
echo '<script src="js/echarts.common.min.js"></script>';

//authorization data
echo '<script type="text/javascript"> var activation = ';
echo (int)$activation;
echo ';
     var inactivation= ';
echo (int)$inactivation;
echo ';</script>';

//build version data (name of each version)
echo '<script type="text/javascript"> var versioninfos= [';
if(count($versioninfos) != 0)
{
  foreach ($versioninfos as $bv){
		  echo "'";
		  echo $bv;
		  echo "',";
  }
}
else
{
  echo "none";
}
echo '];</script>';

//build version data (mount of each version)
echo '<script type="text/javascript"> var versionamounts= [';
if(count($versioninfos) != 0)
{
  foreach ($versionamounts as $bv){
		  echo $bv;
		  echo ', ';
  }
}
else
{
  echo '0';
}
echo '];</script>';

echo '<script type="text/javascript"> var tempdialyOnlineNum = [';
	foreach (array_reverse($dialyOnlineNum) as $bv) {
		echo $bv;
		echo ', ';
	}
echo '];</script>';

echo '<script type="text/javascript"> var tempdatenumber = [';
	foreach (array_reverse($datenumber) as $bv) {
		echo $bv;
		echo ', ';
	}
echo '];</script>';

echo '<script type="text/javascript"> var dialyaverageonlinetime = [';
	foreach (array_reverse($averagedialyonlinetime) as $bv) {
		echo $bv;
		echo ', ';
	}
echo '];</script>';

echo '<script type="text/javascript"> var tdavgonlinetime = ';
echo $tdavgonlinetime;
echo ';
     var tdonlineamount ＝ ';
echo $tdonlineamount;
echo ';</script>';
$todayDate = date("Ym"); //获取当前的年份和月份
//echo '<script> alert(versioninfos); </script>'array_reverse($show_date[$selectedYear])[0];

print <<<EOT
<div class="filter-container ui-tabs-panel ui-widget-content ui-corner-bottom" aria-hidden="false" aria-expanded="true" role="tabpanel" aria-labelledby="ui-id-1">
    
      
    
    <div class="top_center">
		<body style="width: 100%">
			<div id="topOne" style="width: 100%;height:100%;margin:auto"></div>
		</body>
        <script type="text/javascript">
        var myChart = echarts.init(document.getElementById('topOne'));
                option={
                    title: {
                        text: '授权状态统计:'
                    },
                    series : [
                        {
                            
                            type: 'pie',
                            color: ['#0275b8','#778899'],
                            radius: '75%',
                            data:[
                                {value:activation, name:'已激活'},
                                {value:inactivation, name:'未激活'}
                            ],
                            labelLine: {
							  normal: {
								  show: true,
								  length:0.0001,
							  }
							},
                            label: {
                                //显示”名称：数值“
                                //position: 'inner',
                                formatter: '{b}:{c}({d}%)',
                                textStyle:{color:'#000000',fontSize:"12"},
                            },
                            itemStyle: {
                                // emphasis：英文意思是 强调;着重;（轮廓、图形等的）鲜明;突出，重读
                                // emphasis：设置鼠标放到哪一块扇形上面的时候，扇形样式、阴影
                                emphasis: {
                                    shadowBlur: 20,
                                    shadowOffsetX: 3,
                                    shadowColor: 'rgba(30, 144, 255，0.5)'
                                }
                                },
                        }
                    ]
                }
        myChart.setOption(option);
        </script>
    </div>


    
	<div class="top_label">
		<div class="register_info">
		  <p id = "registeramount" style="color:#0275b8;font-size:22px;"></p>
		  <script>document.getElementById("registeramount").innerHTML= "*注册数量: "+registeramount+"  ";</script>
		</div>
	</div>
	
    <div class="top_right">
	  <body style="width: 100%">
		  <div id="first" style="width: 100%;height:100%;margin:auto"></div>
	  </body>
	  <script type="text/javascript">
		  var myChart = echarts.init(document.getElementById('first'));
		  option={
			  title: {
				  text: '在线状态统计:'
			  },
			  series : [
				  {
					  
					  type: 'pie',
					  color: ['#778899','#0275b8'],
					  radius: '75%',
					  data:[
						  {value:onlineamount, name:'在线设备'},
						  {value:registeramount-onlineamount, name:'离线设备'}
					  ],
					  labelLine: {
						normal: {
							show: true,
							length:0.0001,
						}
					  },
					  label: {
						  //显示”名称：数值“
						  //position: 'inner',
						  formatter: '{b}:{c}({d}%)',
						  textStyle:{color:'#000000',fontSize:"12"},
					  },
					  itemStyle: {
						  // emphasis：英文意思是 强调;着重;（轮廓、图形等的）鲜明;突出，重读
						  // emphasis：设置鼠标放到哪一块扇形上面的时候，扇形样式、阴影
						  emphasis: {
						  shadowBlur: 20,
						  shadowOffsetX: 3,
						  shadowColor: 'rgba(30, 144, 255，0.5)'
						  }
					  },
				  }
			  ]
		  }
	  myChart.setOption(option);
	  </script>
    </div>    
    
    
</div>

EOT;
/*comment in 0321
function dates_for_display(){
    $con=mysql_connect("localhost","root");// or die('Error:'.mysql_error());
    if(!$con){
        die("连接失败!".mysql_errno());
    }
    else{
        mysql_select_db("test",$con);
        //distinct values means every extraodinary date.
        $a=mysql_query("select distinct datenote from neokylinestatis;",$con);
        $arr_all_date=array();
        while($temp_all_date=mysql_fetch_array($a)){
            array_push($arr_all_date,$temp_all_date['datenote']);
        }
        mysql_close($con);
        //sort() makes sure that the processing below works no wrong for it based on ordered date array
        sort($arr_all_date); 
        //var_dump($arr_all_date);
        $show_date=[];
        foreach($arr_all_date as $temp_all_date){
            $year_of_date=(int)floor($temp_all_date/10000);
            if(!array_key_exists($year_of_date,$show_date)){
                
                $month_of_year=[];//未定义则置空
                
                $show_date[$year_of_date]=[];  //未定义则定义                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   
            }
            //push month into belonging year
            array_push($month_of_year,(int)floor(($temp_all_date%10000)/100));
            $month_of_year=array_unique($month_of_year);
            $show_date[$year_of_date]=$month_of_year;
        }
        return $show_date;
    }
}

function query_selected_datas($year,$month){
	$datas=array();
    $selectedQueryDateMin=(10000*$year)+(100*$month);
    $selectedQueryDateMax=$selectedQueryDateMin+32;
    //mysql query procedure
    $con=mysql_connect("localhost","root");// or die('Error:'.mysql_error());
    if(!$con){
	    die("连接失败!".mysql_errno());
    }
    else{
        mysql_select_db("test",$con);
        //distinct values means every extraodinary date.
        $qeury=mysql_query("select dailyonlineamount, dailyaverage, datenote from neokylinestatis where datenote < $selectedQueryDateMax and datenote > $selectedQueryDateMin order by datenote;",$con);
		
		//query dailyonlineamount,dailyaverage,days
		$dailyonlineamount=array();
		$dailyaverage=array();
		$days=array();
        while($tmp=mysql_fetch_array($qeury)){
			array_push($dailyonlineamount,$tmp['dailyonlineamount']);
			array_push($dailyaverage,$tmp['dailyaverage']);
			array_push($days,$tmp['datenote']);
		}
		foreach($days as &$bv){//use '&' to quote elements to change itself's value
			$bv=$bv%100;
		}
        mysql_close($con);
	}
	$datas[dailyonlineamount]=$dailyonlineamount;
	$datas[dailyaverage]=$dailyaverage;
	$datas[days]=$days;
	return $datas;
}comment in 0321*/

/**获取用户选择日期 */
if (!empty($_GET['year'])){ //从url获取用户选择的查询年份和月份
    $selectedYear=$_GET['year'];
    $selectedMonth=$_GET['month'];
    if($selectedMonth==0){//为0代表用户选择了某年，月份则为此年记录中最大月份
        $selectedMonth=array_reverse($show_date[$selectedYear])[0];
    }
}
else{//url无值，则默认显示记录中最新日期
    $selectedYear=array_reverse(array_keys($show_date))[0];
    $selectedMonth=array_reverse($show_date[$selectedYear])[0];
}


/* 设置标题日期的变量 */
/*echo '<script>
    var titleYear=';
echo $selectedYear;
echo ';
    var titleMonth=';
echo $selectedMonth;
*/


/* 根据用户选择的日期构造字符串，在下边与系统日期比较 */
if($selectedMonth < 10){
    $selectedYm = "{$selectedYear}0{$selectedMonth}";
}
else{
    $selectedYm = "{$selectedYear}{$selectedMonth}";
}
//comment in 0321
/*$selectedDatas=query_selected_datas($selectedYear,$selectedMonth);
echo '<script> console.log(';
echo $selectedMonth;
echo ');</script>';*/

/*从数据库根据用户选择的日期查询数据 */
$selectedDatas = query_selected_datas($selectedYear,$selectedMonth);

if(count($selectedDatas[days]) != 0)
{
  echo '<script>
    var titleOnline="';
  echo $selectedYear;
  echo '年';
  echo $selectedMonth;
  echo '月设备登陆数量统计';
  echo '";
	 var titleAverage="';
  echo $selectedYear;
  echo '年';
  echo $selectedMonth;
  echo '月平均每日登陆时长';
  echo '"';
}
else
{
  echo '<script>
    var titleOnline="';
  echo '';
  echo ' ";
	 var titleAverage="';
  echo ' "';
}

/**将查询到的数据传递给JS */
if(count($selectedDatas[days]) != 0)
{
  echo ';
	  var dailyonlineamount = [';
  foreach($selectedDatas[dailyonlineamount] as $bv){
	  echo $bv;
	  echo ',';
  }
  if($todayDate == $selectedYm){//若用户选择日期为当前系统日期，则追加今日数据
	  echo $tdonlineamount;
	  echo ',';
  }
  echo '];
	  var dailyaverage = [';

  foreach($selectedDatas[dailyaverage] as $bv){
	  echo $bv;
	  echo ',';
  }
  if($todayDate == $selectedYm){//若用户选择日期为当前系统日期，则追加今日数据
	  echo $tdavgonlinetime;
	  echo ',';
  }
  echo '];
	  var days=[';

  foreach($selectedDatas[days] as $bv){
	  echo $bv;
	  echo ',';
  }
  if($todayDate == $selectedYm){//若用户选择日期为当前系统日期，则追加今日数据
	  echo date("d");
	  echo ',';
  }
  echo '];
  </script>';
}
else 
{
  $td = date('d');
  $noDateDays=[];
  for($bv = 1;$bv <= $td;$bv++)
  {
	array_push($noDateDays, $bv);
  }
  echo ';
	  var dailyonlineamount = [';
  foreach($noDateDays as $bv)
  {
	echo 0;
	echo ',';
  }
  //var_dump(count($selectedDatas['days']));
  //var_dump($noDateDays);
  echo '];
	  var dailyaverage = [';
  foreach($noDateDays as $bv)
  {
	echo 0;
	echo ',';
  }
  echo '];
	  var days=[';
  foreach($noDateDays as $bv)
  {
	echo $bv;
	echo ',';
  }
  echo '];
  </script>';
}

/**HTML标签和改变下拉选择框触发的更改URL的函数 */
echo '
<div class="filter-container ui-tabs-panel ui-widget-content ui-corner-bottom" aria-hidden="false" aria-expanded="true" role="tabpanel" aria-labelledby="ui-id-1">
        <div id="middle">
        
		<div class="selector_container">		
                                
				<select id="months" class="selector" onchange="changeMonth()"></select>
				<select id="years" class="selector" onchange="changeYear()"></select>
        </div>
        <script>
            function changeYear(){
                var myYearSelect=document.getElementById("years");
            
                var yearValue=myYearSelect.options[myYearSelect.selectedIndex].value;
                self.location.href="/Neokylin/neokylin-data-statistics.php?year="+yearValue+"&month="+0;
            }
            function changeMonth(){
                var myMonthSelect=document.getElementById("months");
                var myYearSelect=document.getElementById("years");
            
                var monthValue=myMonthSelect.options[myMonthSelect.selectedIndex].value;
                var yearValue=myYearSelect.options[myYearSelect.selectedIndex].value;
                self.location.href="/Neokylin/neokylin-data-statistics.php?year="+yearValue+"&month="+monthValue;
            }
';


/**根据用户选择的日期为下拉选择框添加数据 设置默认值*/
foreach($show_date[$selectedYear] as $bv){
    echo '  var objSelectNow=document.getElementById("months");';
    if($bv==$selectedMonth){
        echo '
            var objOption = document.createElement("OPTION");
            objOption.text= ';
        echo $bv;
        echo '+"月";
            objOption.value=';
        echo $selectedMonth;
        echo '
            objOption.selected="selected";//this is the selected option if no default 
            objSelectNow.options.add(objOption);';
    }
    else{
        echo '
            var objOption = document.createElement("OPTION");
            objOption.text= ';
        echo $bv;
        echo '+"月";
            objOption.value=';
        echo $bv;
        echo '
            objSelectNow.options.add(objOption);';
    }
}
foreach(array_keys($show_date) as $bv){
    echo '  var objSelectNow=document.getElementById("years");';
    if($bv==$selectedYear){
        echo '
            var objOption = document.createElement("OPTION");
            objOption.text= ';
        echo $bv;
        echo '+"年";
            objOption.value=';
        echo $selectedYear;
        echo '
            objOption.selected="selected";//this is the selected option if no default 
            objSelectNow.options.add(objOption);';
    }
    else{
        echo '
            var objOption = document.createElement("OPTION");
            objOption.text= ';
        echo $bv;
        echo '+"年";
            objOption.value=';
        echo $bv;
        echo '
            objSelectNow.options.add(objOption);';
    }
}
echo '
        </script>';


/**ECharts部分 */
print <<<EOF
                <div class="right">
			<body style="width: 100%">
				<div id="second" style="width: 100%;height:100%;margin:auto"></div>
			
			</body>

            <script type="text/javascript">
	                var myChart = echarts.init(document.getElementById('second'));
	                        option = {
	                                title: {
	                                        text:titleAverage,
	                                },
	                                color: ['#0275b8'],
	                                tooltip : {
	                                        trigger: 'axis',
	                                        axisPointer : {
	                                                type : 'shadow'
	                                        }
	                                },
	                                xAxis: {
	                                        name: '日期',
	                                        type: 'category',
	                                        data: days,
	                                        axisTick: {
	                                                alignWithLabel: true
	                                        }
	                                },
	                                yAxis: {
	                                        name: '时长',
	                                        type: 'value',
	                                        axisLine: {
	                                                symbol: ['none', 'arrow'],
	                                                symbolOffset: [0, 13]
	                                        },
	                                },
	                                series: [{
	                                        name: '时长',
	                                        data: dailyaverage,
	                                        type: 'bar',
	                                        barWidth:'5%'
	                                }]
	                        };
	                myChart.setOption(option);
			</script>
                </div>
                <div class="center">
			<body style="width: 100%">
				<div id="third" style="width: 100%;height:100%;margin:auto"></div>
			</body>
            <script type="text/javascript">
	                var myChart = echarts.init(document.getElementById('third'));
	                        option = {
	                                title: {
	                                        text:titleOnline,
	                                },
	                                color: ['#0275b8'],
	                                tooltip : {
	                                        trigger: 'axis',
	                                        axisPointer : {
	                                                type : 'shadow'
	                                        }
	                                },
	                                xAxis: {
	                                        name: '日期',
	                                        type: 'category',
	                                        data: days,
	                                        axisTick: {
	                                                alignWithLabel: true
	                                        }
	                                },
	                                yAxis: {
	                                        name: '台数',
	                                        type: 'value',
	                                        axisLine: {
	                                                symbol: ['none', 'arrow'],
	                                                symbolOffset: [0, 13]
	                                        },
	                                },
	                                series: [{
	                                        name: '台数',
	                                        data: dailyonlineamount,
	                                        type: 'bar',
	                                        barWidth:'5%'
	                                }]
	                        };
	                myChart.setOption(option);
			</script>
                </div>
        </div>
</div>

EOF;

//The EOP segement was generated on 28 Feb, 2019
/**ECharts部分 */
print <<<EOP
<div class="filter-container ui-tabs-panel ui-widget-content ui-corner-bottom" aria-hidden="false" aria-expanded="true" role="tabpanel" aria-labelledby="ui-id-1">
        <! 作为footer在底部显示>
        <div id="footer" >
                
                <div class="main">
			<body style="width: 100%">
				<! 比例显示>
				<div id="main" style="width: 100%;height:300%;"></div>
    <script type="text/javascript">
        // 基于准备好的dom，初始化echarts实例
        var myChart = echarts.init(document.getElementById('main'));

        // 指定图表的配置项和数据
        var option = {
            title: {
                text: '系统版本状态统计'
            },
            grid: {
                x: '18%',
                x2: '5%'
            },
            tooltip: {},
            color: ['#0275b8'],
            legend: {
                data:['数量']
            },
            yAxis: {
                data: versioninfos,
                rotate: 40
            },
            xAxis: {
            },
            series: [{
                name: '数量',
                type: 'bar',
// 		barWidth:'30%',
                data: versionamounts
            }]
        };

        // 使用刚指定的配置项和数据显示图表。
        myChart.setOption(option);
    </script>

			</body>	
                </div>
        </div>
</div>
EOP;
echo "</div></body>";

echo '</html>';



}

exit;
